summaryrefslogtreecommitdiff
path: root/gtk2_ardour/plugin_ui.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2015-09-04 11:49:56 -0400
committerPaul Davis <paul@linuxaudiosystems.com>2016-02-22 15:31:24 -0500
commitec65e351acea329de1d09b8ce518a023001dfdab (patch)
treeed622b2e6b7435d3a7d45de22d3c734699930ece /gtk2_ardour/plugin_ui.cc
parenta47b3c4dc56c8c5c51dd46b45328c37b740d05ab (diff)
ensure that all callers of ARDOUR_UI_UTILS::relay_key_press() provide a window
Diffstat (limited to 'gtk2_ardour/plugin_ui.cc')
-rw-r--r--gtk2_ardour/plugin_ui.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk2_ardour/plugin_ui.cc b/gtk2_ardour/plugin_ui.cc
index 833055eff7..87c0202836 100644
--- a/gtk2_ardour/plugin_ui.cc
+++ b/gtk2_ardour/plugin_ui.cc
@@ -369,12 +369,12 @@ PluginUIWindow::on_key_press_event (GdkEventKey* event)
if (_pluginui) {
_pluginui->grab_focus();
if (_pluginui->non_gtk_gui()) {
/* pass editor window as the window for the event
to be handled in, not this one, because there are
no widgets in this window that we want to have
key focus.
*/
- return relay_key_press (event, 0);
+ return relay_key_press (event, &ARDOUR_UI::instance()->main_window());
} else {
return relay_key_press (event, this);
}
@@ -369,12 +369,12 @@ PluginUIWindow::on_key_press_event (GdkEventKey* event)
_pluginui->grab_focus();
if (_pluginui->non_gtk_gui()) {
- /* pass editor window as the window for the event
+ /* pass main window as the window for the event
to be handled in, not this one, because there are
no widgets in this window that we want to have